# Security Policy

## Supported Versions

We support the latest release of Fabra.

| Version | Supported          |
| ------- | ------------------ |
| Latest  | :white_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

We take the security of Fabra seriously. If you discover a security vulnerability, please do not report it as a public issue on GitHub.

Instead, please report it by emailing **dahmann@lumyn.cc**.

We will:
1.  Acknowledge your report within 48 hours.
2.  Investigate the issue and update you on our findings.
3.  Release a fix if necessary and credit you for the discovery (unless you prefer to remain anonymous).

Thank you for helping keep Fabra secure!
